@@ -1,6 +1,6 @@
 package App::Genpass;
 BEGIN {
-  $App::Genpass::VERSION = '2.03';
+  $App::Genpass::VERSION = '2.04';
 }
 # ABSTRACT: Quickly and easily create secure passwords
 
@@ -253,7 +253,7 @@ App::Genpass - Quickly and easily create secure passwords
 
 =head1 VERSION
 
-version 2.03
+version 2.04
 
 =head1 SYNOPSIS
 
@@ -271,7 +271,7 @@ If you've ever needed to create 10 (or even 10,000) passwords on the fly with
 varying preferences (lowercase, uppercase, no confusing characters, special
 characters, minimum length, etc.), you know it can become a pretty pesky task.
 
-This script makes it possible to create flexible and secure passwords, quickly
+This module makes it possible to create flexible and secure passwords, quickly
 and easily.
 
     use App::Genpass;
@@ -282,6 +282,10 @@ and easily.
     my @multiple_passwords = $genpass->generate(10); # returns array again
     my $multiple_passwords = $genpass->generate(10); # returns arrayref
 
+This distribution includes a program called B<genpass>, which is a command line
+interface to this module. If you need a program that generates passwords, use
+B<genpass>.
+
 =for stopwords boolean DWIM DWYM arrayref perldoc Github CPAN's AnnoCPAN CPAN
 
 =head1 SUBROUTINES/METHODS
